@@ -1,6 +1,9 @@
+from .examples import chat_prompt_template_examples
 from .prompt import (
     ChatPrompt,
     ChatPromptTemplate,
+    CompleteChatPromptTemplate,
+    CompleteTextPromptTemplate,
     CreateCompletionPrompt,
     GeneratedFields,
     GetCompletionPrompt,
